@@ -2,6 +2,5 @@ package # hide from PAUSE
     MyBlog::Model::DBIC;
 
 use strict;
-use base 'Catalyst::Model::DBIC::Schema';
-
+use base qw(Catalyst::Model::DBIC::Schema);
 1;
